==> cqrcode-0.9.tar.gz: cqrcode-0.9/setup.py <==
import setuptools

setuptools.setup(name='cqrcode',
                 version='0.9',
                 description='Generate a QR code that can adapt to the cylinder',
                 long_description=open('README.md', 'r', encoding='utf-8').read(),
                 author='jiaming',
                 author_email='837357785@qq.com',
                 url = 'https://pypi.org/project/cqrcode/',
                 license='MIT',
                 packages=setuptools.find_packages(),
                 zip_safe=False,
                 include_package_data=True,
                 install_requires = [
                    'Pillow==6.1.0',
                    'pyzbar==0.1.8',
                    'qrcode==6.1',
                    'PySnooper==0.2.8',
                    'pretty-errors==1.2.7',
                    'matplotlib==3.0.3',
                 ],
                 keywords='cylinder qrcode',
                 classifiers=[
                     "Natural Language :: Chinese (Simplified)",
                     "Development Status :: 3 - Alpha",
                     "Operating System :: OS Independent",
                     "Programming Language :: Python",
                     "Programming Language :: Python :: 3.4",
                     "Programming Language :: Python :: 3.5",
                     "Programming Language :: Python :: 3.6",
                     "Programming Language :: Python :: 3.7",
                     "License :: OSI Approved :: MIT License",
                     "Topic :: Utilities"
                 ],
)

==> cqrcode-0.11.tar.gz: cqrcode-0.11/setup.py <==
import setuptools

setuptools.setup(name='cqrcode',
                 version='0.11',
                 description='Generate a QR code that can adapt to the cylinder',
                 long_description=open('README.md', 'r', encoding='utf-8').read(),
                 author='jiaming',
                 author_email='837357785@qq.com',
                 url = 'https://pypi.org/project/cqrcode/',
                 license='MIT',
                 packages=setuptools.find_packages(),
                 zip_safe=False,
                 include_package_data=True,
                 install_requires = [
                    'Pillow>=6.1.0',
                    'pyzbar>=0.1.8',
                    'qrcode>=6.1',
                    'PySnooper>=0.2.8',
                    'pretty-errors>=1.2.7',
                    'matplotlib>=3.0.3',
                 ],
                 keywords='cylinder qrcode',
                 classifiers=[
                     "Natural Language :: Chinese (Simplified)",
                     "Development Status :: 3 - Alpha",
                     "Operating System :: OS Independent",
                     "Programming Language :: Python",
                     "Programming Language :: Python :: 3.4",
                     "Programming Language :: Python :: 3.5",
                     "Programming Language :: Python :: 3.6",
                     "Programming Language :: Python :: 3.7",
                     "License :: OSI Approved :: MIT License",
                     "Topic :: Utilities"
                 ],
)
